.. image:: https://travis-ci.org/gisce/esios.svg?branch=master
    :target: https://travis-ci.org/gisce/esios

E.Sios API
==========

Interact with e.sios API

http://esios.readthedocs.org/

Usage
------

Ensure that ``ESIOS_TOKEN`` var exists and is exported for the working env.
